(function($) {
	/*
		======== A Handy Little QUnit Reference ========
		http://api.qunitjs.com/

		Test methods:
			module(name, {[setup][ ,teardown]})
			test(name, callback)
			expect(numberOfAssertions)
			stop(increment)
			start(decrement)
		Test assertions: 
			ok(value, [message])
			equal(actual, expected, [message])
			notEqual(actual, expected, [message])
			deepEqual(actual, expected, [message])
			notDeepEqual(actual, expected, [message])
			strictEqual(actual, expected, [message])
			notStrictEqual(actual, expected, [message])
			throws(block, [expected], [message])
	*/

	QUnit.module('jQuery.whereyat', {
		beforeEach: function() {
			$('body').addClass('whereyat');
		},
		afterEach: function() {
			$('body').removeClass();
			$.mockjax.clear();
		}
	});

	QUnit.test('has body class for yat-xs', function(assert) {
		assert.expect(2);
		var done = assert.async();
		$.mockjax({
			url: "https://ip.wherey.at/",
			dataType: "json",
			responseText: {
				status: "ok",
				city: "New Orleans",
				country: "United States",
				subdivisions: [
					{ name: "Louisiana" }
				],
				latitude: 30,
				longitude: -90,
				time_zone: "America/Chicago"
			}
		});
		$.whereyat({}, function(){
			assert.ok($('body').hasClass('yat-xs'), "body should have class yat-xs, has: " + $('body').attr('class'));
			assert.equal($('body').attr('class'), "whereyat yat-xs", "body should only have expected classes");
			done();
		});
	});
	
	QUnit.test('has body class for yat-sm', function(assert) {
		var done = assert.async();
		assert.expect(2);
		$.mockjax({
			url: "https://ip.wherey.at/",
			dataType: "json",
			responseText: {
				status: "ok",
				city: "Erath",
				country: "United States",
				subdivisions: [
					{ name: "Louisiana" }
				],
				latitude: 30,
				longitude: -92,
				time_zone: "America/Chicago"
			}
		});
		$.whereyat({}, function(){
			assert.ok($('body').hasClass('yat-sm'), "body should have class yat-sm, has: " + $('body').attr('class'));
			assert.equal($('body').attr('class'), "whereyat yat-sm", "body should only have expected classes");
			done();
		});
	});
	
	QUnit.test('has body class for yat-md', function(assert) {
		assert.expect(2);
		var done = assert.async();
		$.mockjax({
			url: "https://ip.wherey.at/",
			dataType: "json",
			responseText: {
				status: "ok",
				city: "Dayton",
				country: "United States",
				subdivisions: [
					{ name: "Texas" }
				],
				latitude: 30,
				longitude: -95,
				time_zone: "America/Chicago"
			}
		});
		$.whereyat({}, function(){
			assert.ok($('body').hasClass('yat-md'), "body should have class yat-md, has: " + $('body').attr('class'));
			assert.equal($('body').attr('class'), "whereyat yat-md", "body should only have expected classes");
			done();
		});
	});
	
	QUnit.test('has body class for yat-lg', function(assert) {
		assert.expect(2);
		var done = assert.async();
		$.mockjax({
			url: "https://ip.wherey.at/",
			dataType: "json",
			responseText: {
				status: "ok",
				city: "Santa Rosa",
				country: "United States",
				subdivisions: [
					{ name: "New Mexico" }
				],
				latitude: 35,
				longitude: -105,
				time_zone: "America/Mountain"
			}
		});
		$.whereyat({}, function(){
			assert.ok($('body').hasClass('yat-lg'), "body should have class yat-lg, has: " + $('body').attr('class'));
			assert.equal($('body').attr('class'), "whereyat yat-lg", "body should only have expected classes");
			done();
		});
	});
	
	QUnit.test('has body class for yat-xl', function(assert) {
		assert.expect(2);
		var done = assert.async();
		$.mockjax({
			url: "https://ip.wherey.at/",
			dataType: "json",
			responseText: {
				status: "ok",
				city: "San Francisco",
				country: "United States",
				subdivisions: [
					{ name: "California" }
				],
				latitude: 37,
				longitude: -122,
				time_zone: "America/Pacific"
			}
		});
		$.whereyat({}, function(){
			assert.ok($('body').hasClass('yat-xl'), "body should have class yat-xl, has: " + $('body').attr('class'));
			assert.equal($('body').attr('class'), "whereyat yat-xl", "body should only have expected classes");
			done();
		});
	});
	
	QUnit.test('has body classes for not_found', function(assert) {
		assert.expect(2);
		var done = assert.async();
		$.mockjax({
			url: "https://ip.wherey.at/",
			dataType: "json",
			responseText: {
				status: "not_found"
			}
		});
		$.whereyat({}, function(){
			assert.ok($('body').hasClass('yat-error'), "body should have class yat-error, has: " + $('body').attr('class'));
			assert.equal($('body').attr('class'), "whereyat yat-error", "body should only have expected classes");
			done();
		});
	});

}(jQuery));
